About
=====

This package provides a python wrapper to the Montage Astronomical Image Mosaic
Engine, including both functions to access individual Montage commands, and
high-level functions to facilitate mosaicking and re-projecting.

.. image:: https://travis-ci.org/astropy/montage-wrapper.png?branch=master
  :target: https://travis-ci.org/astropy/montage-wrapper

.. image:: https://coveralls.io/repos/astropy/montage-wrapper/badge.png
  :target: https://coveralls.io/r/astropy/montage-wrapper
